import java.util.ArrayList;

/**
 * Stores the path as strings and information about it.
 * It stores the start, current position and if it is a dead end.
 *
 * @author                  Dylan McKendry
 */

public class Path
{
    private String directions = "";

    private int currentX;
    private int currentY;

    private boolean deadEnd = false;

   /**
    * A constructor for Path.
    * It loads the start position in.
    *
    * @param  startX      a int of the starting x coordinate
    * @param  startY      a int of the starting y coordinate
    */
    public Path(int startX, int startY)
    {
        currentX = startX;
        currentY = startY;
    }
    

   /**
    * A constructor for Path.
    * It loads the start position in and any previous directions.
    *
    * @param  directions    a string of previous directions
    * @param  currentX      a int of the starting x coordinate
    * @param  currentX      a int of the starting y coordinate
    */
    public Path(String directions, int currentX, int currentY)
    {
        this.directions = directions;
        this.currentX = currentX;
        this.currentY = currentY;
    }
    

    public int getX()
    {
        return currentX;
    }
    

    public int getY()
    {
        return currentY;
    }

    public String getDirections()
    {
        return directions;
    }
    

   /**
    * Adds a character to the string directions and updates its position.
    *
    * @param  c             the character to add to the directions
    */
    public void addChar(char c)
    {
        directions += c;
        switch (c) {
            case 'R':
                currentX++;
                break;
            case 'L':
                currentX--;
                break;
            case 'U':
                currentY--;
                break;
            case 'D':
                currentY++;
                break;
        }
    }  
    
    public void deadEnd()
    {
        deadEnd = true;
    }
    
    public boolean isDeadEnd()
    {
        return deadEnd;
    }


}